pub fn platform_scroll_config() -> PlatformScrollConfigExpand description
Returns the platform scroll configuration for the current target.
pub fn platform_scroll_config() -> PlatformScrollConfigReturns the platform scroll configuration for the current target.